@@ -821,7 +821,7 @@ class MultiProject(QObject):
             idx += 1
         
         self.recentMenu.addSeparator()
-        self.recentMenu.addAction(self.tr('&Clear'), self.__clearRecent)
+        self.recentMenu.addAction(self.tr('&Clear'), self.clearRecent)
     
     def __openRecent(self, act):
         """
@@ -834,11 +834,12 @@ class MultiProject(QObject):
         if file:
             self.openMultiProject(file)
     
-    def __clearRecent(self):
+    def clearRecent(self):
         """
-        Private method to clear the recent multi projects menu.
+        Public method to clear the recent multi projects menu.
         """
         self.recent = []
+        self.__saveRecent()
     
     def getActions(self):
         """
